@@ -195,7 +195,7 @@ def init():
 
         except:
             print("webhook already exists on this repository ")
-
+            flag=0
             #   pull
 
             for i in range(3):
@@ -215,17 +215,23 @@ def init():
                     repo = git.Repo(path)
                     origin = repo.remote(name='origin')
                     res=origin.pull()
-                    print("pull succeessfull")
+                    print("Looking for Pull Opeartion")
                     time.sleep(10)
-                    val=0
+                    flag=flag+1
+                    
                 else:
                     print("no files to pull")
                     time.sleep(10)
+                    flag=0
 
             curtime = datetime.datetime.now()
             response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username})
            #success , project id , repo name , current date and time , email id'
-            print("status code is ",response2.status_code)
+            if(flag>0):
+                print('Pull operation successfull')
+            else:
+                print("No files for pull found")
+            # print("status code is ",response2.status_code)
 
           
     except:
